@@ -57,7 +57,12 @@ def _get_lyrics(page_title):
 		"format": "json",
 		}
 	
-	content = json.loads(_download(args))["query"]["pages"].popitem()[1]["revisions"][0]["*"]
+	revisions = json.loads(_download(args))["query"]["pages"].popitem()[1]
+	
+	if not "revisions" in revisions:
+		return None
+		
+	content = revisions["revisions"][0]["*"]
 	if "<lyrics>" in content:
 		return content[content.find("<lyrics>") + len("<lyrics>") : content.find("</lyrics>")].strip()
 
